#ifndef MPCLIENT_H
#define MPCLIENT_H

#include <string>
#include <vector>
#include <queue>
#include <ogc/mutex.h>
#include "lineclient.h"

struct MPReply
{
	std::string command;
	std::vector<std::string> responses;
	std::string completion_code; // set to "" (socket error), "OK", or "ACK ..."
};

class MPClient
{
public:
	MPClient();
	~MPClient();

	bool init(const std::string& host, int port);
	bool connected() { return m_lineclient.connected(); }

	void sendCommand(const std::string& command);
	bool hasReply();
	bool getReply(MPReply* reply);

private:
	static void* static_commloop(void* mpclient);
	void commloop();
	std::vector<std::string> receive_reply();

	std::string m_host;
	int m_port;
	LineClient m_lineclient;
	bool m_shutdown;

	mutex_t m_command_fifo_mutex;
	mutex_t m_reply_fifo_mutex;
	std::queue<std::string> m_command_fifo;
	std::queue<MPReply> m_reply_fifo;
};

#endif
